import re

ENGLISH = "en"
FRENCH = "fr"

# English triggers (over 50 real expressions/words/phrases commonly related to eCommerce purchase intent)
REQUEST_TRIGGERS_EN = [
    "some",
    "looking for",
    "looking to buy",
    "looking to purchase",
    "searching for",
    "interested in",
    "do you have",
    "do you sell",
    "is there",
    "are there",
    "would like",
    "would love",
    "can you find",
    "could you find",
    "find me",
    "show me",
    "give me",
    "can you suggest",
    "could you suggest",
    "can you recommend",
    "could you recommend",
    "what is the price of",
    "how much is",
    "how much are",
    "how much for",
    "buy",
    "purchase",
    "need",
    "want",
    "require",
    "find",
    "get",
    "sell",
    "have",
    "suggest",
    "recommend",
    "show",
    "maybe",
    "maybe?",
    "wish to buy",
    "wish to order",
    "plan to purchase",
    "i'm in the market for",
    "hoping to buy",
    "consider buying",
    "in need of",
    "seeking",
    "eager to acquire",
    "where can i find",
    "intent to order",
    "looking up pricing",
    "checking cost",
    "thinking of buying",
    "shopping for",
    "add to cart",
    "add item",
    "add product",
    "available for sale",
    "do you stock",
    "do you carry",
    "order now",
    "place an order",
    "get a quote",
    "quote me",
    "requesting price",
    "requesting availability",
    "is it available",
    "could i buy",
    "could i order",
    "looking to place an order",
    "looking to add",
    "how do i buy",
    "need pricing",
    "need costs",
    "compare prices",
    "purchase option",
    "purchase options",
    "looking for deals",
    "special offer",
    "intent to purchase",
    "ready to buy",
    "ready to purchase",
]

# English filler phrases (common extraneous words/phrases to strip away from the actual request)
FILLER_PHRASES_EN = [
    "some",
    "i need",
    "i want",
    "i would like",
    "i'd like",
    "i wanna",
    "i am looking for",
    "i'm looking for",
    "i am interested in",
    "i'm interested in",
    "i am searching for",
    "i'm searching for",
    "we need",
    "we want",
    "we are looking for",
    "we are interested in",
    "please",
    "could you",
    "can you",
    "would you",
    "show me",
    "find me",
    "get me",
    "give me",
    "do you have",
    "do you sell",
    "is there",
    "are there",
    "what is the price of",
    "what are the prices of",
    "how much is",
    "how much are",
    "how much for",
    "suggest",
    "recommend",
    "can you find",
    "could you find",
    "could you suggest",
    "could you recommend",
    "i'm in the market for",
    "i'm in need of",
    "i hope to get",
    "i plan to buy",
    "i think i might buy",
    "i was considering",
    "i was wondering if",
    "i'm hoping you have",
    "just checking if",
    "could it be possible",
    "any chance you have",
    "any possibility of",
    "would it be possible to",
    "looking to possibly",
    "just inquiring about",
    "let me know if you have",
    "is it in stock",
    "are they in stock",
    "would like to see",
    "would like to check",
    "i was curious about",
    "hoping you could",
    "wonder if i could",
    "i might need",
    "potentially might want",
    "wondering if available",
    "do i have the option",
    "can i see if",
    "can i see any",
    "please let me know",
    "would love to see",
    "would love to check",
    "i am hoping for",
    "i am hoping to get",
]

REQUEST_TRIGGERS_EN = [t.lower() for t in REQUEST_TRIGGERS_EN]
FILLER_PHRASES_EN = [f.lower() for f in FILLER_PHRASES_EN]


# French triggers (over 50 real expressions/words/phrases commonly related to eCommerce purchase intent)
REQUEST_TRIGGERS_FR = [
    "je cherche",
    "je suis intéressé par",
    "j'aimerais acheter",
    "est-ce que vous avez",
    "est-ce que vous vendez",
    "est-ce qu'il y a",
    "est-ce qu'il existe",
    "pourrais-je trouver",
    "peux-tu trouver",
    "montre-moi",
    "donne-moi",
    "je voudrais",
    "j'aimerais avoir",
    "acheter",
    "besoin",
    "veux",
    "voudrais",
    "trouver",
    "obtenir",
    "vendre",
    "avoir",
    "suggérer",
    "recommander",
    "montrer",
    "peut-être",
    "peutetre",
    "peutetre?",
    "je souhaite acheter",
    "je veux commander",
    "je prévois d'acquérir",
    "je compte acheter",
    "je regarde pour",
    "je recherche",
    "intéressé à acquérir",
    "où puis-je trouver",
    "je souhaite passer commande",
    "je souhaite obtenir",
    "comparer les prix",
    "je veux un devis",
    "j'aimerais un devis",
    "je veux une estimation",
    "est-ce disponible",
    "est-ce que c'est disponible",
    "est-ce que vous stockez",
    "proposez-vous",
    "avez-vous en vente",
    "besoin de commander",
    "besoin d'acheter",
    "j'ai l'intention d'acheter",
    "j'envisage d'acheter",
    "envisage d'acquérir",
    "demander un prix",
    "demander un tarif",
    "quelle est la disponibilité",
    "possible d'acheter",
    "possible de commander",
    "je regarde pour acheter",
    "je compte passer commande",
    "je désire acheter",
    "je désire commander",
    "achetons",
    "commandons",
    "obtention possible",
    "je ferais l'achat de",
    "je ferais la commande de",
    "est-il possible de",
    "peut-on se procurer",
    "je me demande si vous avez",
    "y a-t-il en stock",
    "disponible à la vente",
    "intéressé par l'achat",
    "je songe à acheter",
    "je songe à commander",
    "je voudrais passer commande",
]

# French filler phrases (common extraneous words/phrases to strip away from the actual request)
FILLER_PHRASES_FR = [
    "je cherche",
    "je suis intéressé par",
    "j'aimerais acheter",
    "je veux",
    "je voudrais",
    "j'aimerais",
    "est-ce que vous avez",
    "est-ce que vous vendez",
    "est-ce qu'il y a",
    "est-ce qu'il existe",
    "peux-tu",
    "pourrais-tu",
    "pourriez-vous",
    "montre-moi",
    "donne-moi",
    "fais-moi",
    "combien coûte",
    "quel est le prix",
    "quel est son prix",
    "je regarde pour",
    "intéressé à acquérir",
    "où puis-je trouver",
    "je souhaite passer commande",
    "comparer les prix",
    "je veux un devis",
    "j'aimerais un devis",
    "je veux une estimation",
    "est-ce disponible",
    "est-ce que c'est disponible",
    "est-ce que vous stockez",
    "proposez-vous",
    "avez-vous en vente",
    "j'ai l'intention d'acheter",
    "j'envisage d'acheter",
    "demander un prix",
    "demander un tarif",
    "quelle est la disponibilité",
    "possible d'acheter",
    "possible de commander",
    "je regarde pour acheter",
    "je compte passer commande",
    "je désire acheter",
    "je désire commander",
    "achetons",
    "commandons",
    "obtention possible",
    "je ferais l'achat de",
    "je ferais la commande de",
    "peut-on se procurer",
    "je me demande si vous avez",
    "y a-t-il en stock",
    "disponible à la vente",
    "intéressé par l'achat",
    "je songe à acheter",
    "je songe à commander",
    "pourrais-je trouver",
    "peux-tu trouver",
    "peut-être",
    "peutetre",
    "peutetre?",
    "suggérer",
    "recommander",
    "montrer",
]

REQUEST_TRIGGERS_FR = [t.lower() for t in REQUEST_TRIGGERS_FR]
FILLER_PHRASES_FR = [f.lower() for f in FILLER_PHRASES_FR]

# for budget

EN_BUDGET_HINTS = [
    "only have",
    "can only spend",
    "limit is",
    "my limit is",
    "maximum is",
    "max is",
    "i can't spend more than",
    "i cannot spend more than",
    "only got",
    "i only got",
    "i just have",
    "i've just got",
    "my budget is",
    "my total is",
    "spending cap is",
    "i can only afford",
    "my spending limit",
    "my max budget",
    "i do not want to exceed",
    "the highest i can pay",
    "the highest i can go",
    "the maximum i can go",
    "i can't exceed",
    "can't exceed",
    "can't go beyond",
    "won't go over",
    "budget limit",
    "imposed limit of",
    "i have to keep it under",
    "i must keep it under",
    "my budget does not exceed",
    "i plan to spend no more than",
    "i don't plan to spend more than",
    "i am restricted to",
    "i am constrained to",
    "i can't surpass",
]

FR_BUDGET_HINTS = [
    "je n'ai que",
    "ma limite",
    "mon budget",
    "je ne peux dépenser",
    "je ne peux que dépenser",
    "limite de",
    "limite est",
    "ma limite est",
    "maximum est",
    "je ne peux pas dépasser",
    "je n'ai pas plus de",
    "je n'ai pas au-delà de",
    "je ne vais pas dépasser",
    "je ne veux pas dépasser",
    "je ne peux pas aller au-delà de",
    "je ne peux plus",
    "je ne vais pas aller au-dessus de",
    "je ne vais pas aller plus loin que",
    "mon plafond de dépense",
    "mon plafond est",
    "je ne veux pas aller plus haut que",
    "je suis limité à",
    "je suis contraint à",
    "ma contrainte est de",
    "je ne dois pas dépasser",
    "je ne passerai pas au-dessus de",
    "je dois rester sous",
    "je compte rester sous",
    "je ne souhaite pas dépenser plus de",
    "je n'ai pas le budget pour dépasser",
    "je suis obligé de rester sous",
    "limite de mon budget",
    "je ne dispose que de",
    "je ne peux aller au-delà",
]

# for currency
CURRENCY_ONLY_PATTERN = re.compile(
    r"(usd|eur|gbp|cad|aud|inr|jpy|chf|krw|sar|dirham|dhs|"
    r"dollars?|euros?|pounds?|yen|rupees?|\$|€|£)",
    re.IGNORECASE,
)
MONEY_PATTERN = re.compile(
    r"(\d+(?:\.\d+)?)(?:\s*(usd|eur|gbp|cad|aud|inr|jpy|chf|krw|sar|dirham|dhs|"
    r"dollars?|euros?|pounds?|yen|rupees?|\$|€|£))?",
    re.IGNORECASE,
)
CURRENCY_MAP = {
    "$": "usd",
    "dollar": "usd",
    "dollars": "usd",
    "usd": "usd",
    "€": "eur",
    "eur": "eur",
    "euro": "eur",
    "euros": "eur",
    "£": "gbp",
    "pound": "gbp",
    "pounds": "gbp",
    "gbp": "gbp",
    "cad": "cad",
    "aud": "aud",
    "inr": "inr",
    "jpy": "jpy",
    "yen": "jpy",
    "chf": "chf",
    "krw": "krw",
    "sar": "sar",
    "dirham": "aed",
    "dhs": "aed",
    "rupee": "inr",
    "rupees": "inr",
}
